@@ -71,7 +71,7 @@ include("mymatrix.jl")
             @test Matrix(sparse(A)) ≈ Matrix(A)
 
             @test Matrix(A') ≈ Matrix(A)'
-            @test Matrix(transpose(A)) ≈ transpose(Matrix(A))
+            @test Matrix(transpose(A)) ≈ copy(transpose(A)) ≈ transpose(Matrix(A))
             @test Matrix((A+im*A)') ≈ (Matrix(A)+im*Matrix(A))'
             @test Matrix(transpose(A+im*A)) ≈ transpose(Matrix(A)+im*Matrix(A))
 
@@ -551,11 +551,19 @@ include("mymatrix.jl")
 
     @testset "offset views" begin
         B = BandedMatrix(0=>1:4)
-        A = view(B, Base.IdentityUnitRange(2:4), 1:4)
-        @test !any(in(axes(A,1)), BandedMatrices.colrange(A, 1))
-        @test BandedMatrices.colrange(A, 2) == 2:2
-        @test BandedMatrices.colrange(A, 3) == 3:3
-        @test BandedMatrices.colrange(A, 4) == 4:4
+        for A in (view(B, Base.IdentityUnitRange(2:4), 1:4), view(B, 1:4, Base.IdentityUnitRange(2:4)), view(B, Base.IdentityUnitRange(2:4), Base.IdentityUnitRange(2:4)))
+            @test A[2,2] == B[2,2] == 2 # indexing matches
+            @test bandwidths(A) == bandwidths(B) == (0,0) # therefore bandwidths are unchanged
+            if 1 ∉ parentindices(A)[1]
+                @test !any(in(axes(A,1)), BandedMatrices.colrange(A, 1))
+            end
+            @test BandedMatrices.colrange(A, 2) == 2:2
+            @test BandedMatrices.colrange(A, 3) == 3:3
+            @test BandedMatrices.colrange(A, 4) == 4:4
+            @test BandedMatrices.rowrange(A, 2) == 2:2
+            @test BandedMatrices.rowrange(A, 3) == 3:3
+            @test BandedMatrices.rowrange(A, 4) == 4:4
+        end
     end
 
     @testset "resize" begin
